This is a slab-allocator inspired by the slab crate, with the main
difference being it allocates pinned fixed sized arrays instead of using a
resizable Vec. This lets us guarantee that none of the pooled objects will
be moved unless we first remove it from the pool.
Structs
- Iter
- An iterator over the values stored in the
Slab - IterMut
- An iterator over the values stored in the
Slab - Slab
- The slab-allocator (also known as an object pool) struct.
Constants
- CHUNK_
SIZE - The number of elements in each
Chunk’s array. This can be removed once const generics are stable.